def print_lol(the_list, tabcount=0):
	for each_item in the_list:
		if isinstance(each_item, list):
			print_lol(each_item, tabcount+1)
		else:
			for num in range(tabcount):
				print('\t', end='')
			print (each_item)

